from ts_t1_validator.models.enums.frequency_type import FrequencyTypeEnum
from ts_t1_validator.validators.exceptions import ValidationException
from ts_t1_validator.validators.rules.abstract_rule import ValidationRule


class StrategyFrequencyTypeForPGRule(ValidationRule):
    def __init__(self, frequency_type: FrequencyTypeEnum):
        self.frequency_type = frequency_type

    def execute(self):
        """
        Case:
        For PG campaign frequency_type must be the only 'no-limit'
        """
        if self.frequency_type is not FrequencyTypeEnum.NO_LIMIT:
            raise ValidationException("'frequency_type' must be 'no-limit' for Programmatic Guaranteed campaign")



from ts_t1_validator.models.enums.frequency_type import FrequencyTypeEnum
from ts_t1_validator.validators.exceptions import ValidationException
from ts_t1_validator.validators.rules.abstract_rule import ValidationRule


class StrategyUseOptimizationForPGRule(ValidationRule):
    def __init__(self, use_optimization: bool):
        self.use_optimization = use_optimization

    def execute(self):
        """
        Case:
        For PG campaign use_optimization must be False
        """
        if self.use_optimization is True:
            raise ValidationException("'use_optimization' must be False for Programmatic Guaranteed campaign")



from ts_t1_validator.models.enums.goal_type import GoalTypeEnum
from ts_t1_validator.validators.exceptions import ValidationException
from ts_t1_validator.validators.rules.abstract_rule import ValidationRule


class StrategyGoalTypesForPGRule(ValidationRule):
    def __init__(self, goal_type: GoalTypeEnum):
        self.goal_type = goal_type

    def execute(self):
        """
        Case:
         For PG campaign the only type is 'spend'
        """
        if self.goal_type not in [GoalTypeEnum.SPEND]:
            raise ValidationException("'goal_type' must be 'spend' for Programmatic Guaranteed campaign")
